/// Persistence of Vision Ray Tracer Scene Description File
// File: bell.inc
// Vers: 3.1
// Desc: For the Internet Ray Tracing Competition
// Date: 02/27/99
// Auth: Bob Franke
//


#version 3.1;

#include "colors.inc" 
#include "textures.inc" 


#declare bolt_Rusty_Iron = 
texture {
    pigment {
        granite                          
        color_map {
            [0.0 rgb <0.42, 0.20, 0.20>*.85]
            [0.5 rgb <0.50, 0.50, 0.02>*.85]
            [0.6 rgb <0.60, 0.20, 0.20>*.85]
            [0.6 rgb <0.30, 0.20, 0.20>*.85]
        }
    }
    finish { ambient 0.2 diffuse 0.6 }
    normal { wrinkles 1 scale 0.1 }
}

#declare oneLink=
union{
  object{
    torus { .75/12, .25/12}
    clipped_by{plane{x,0}}
    texture{Rusty_Iron } 
  }
  cylinder{<0,0,.75/12>,<1.5/12,0,.75/12>,.25/12}
  cylinder{<0,0,-.75/12>,<1.5/12,0,-.75/12>,.25/12}
  object{
    torus { .75/12, .25/12}
    clipped_by{plane{x,0 inverse}}
    translate<1.5/12,0,0>
    texture{Rusty_Iron}
  }
   texture{Rusty_Iron}
}

#declare bellMetal =
texture {
  pigment {
    marble
    turbulence 4              
    color_map {
      [0.0 color Bronze]
      [0.3 color Bronze]
      [0.5 color Bronze*1.5]
      [1.0 color Bronze*1.5] 
    }
    scale 0.2
  }
  normal {granite .0625}
  finish {Dull crand 0.2}
}

#declare bellWood =  
pigment {
  wood
  turbulence 0.1            
  scale <0.2, 0.2, 1>       
  color_map {
    [0.1 rgb <0.42, 0.26, 0.15>*2]
    [0.9 rgb <0.52, 0.37, 0.26>*2]
  }
}

#declare woodCracks = 
pigment {
  marble
  turbulence .5
  color_map {
    [0.0 rgbf <1,1,1,1>]
    [0.90 rgbf <1,1,1,1>]
    [0.90 rgbf <.1,.1,.1,0>]
    [1.0 rgbf <0,0,0,0>]
  }
}

#declare bellShape=
sor{15,
    <0,0> <34,6> <47,11> 
    <53,13> <55,19>  <56,43> 
    <57,67> <58,86> <63,103> 
    <70,117> <76,126> <81,131> 
    <87,138> <90,144> <91,152> 
}
    

#declare bell_Iron = 
texture {
  pigment{Bronze} 
  finish { ambient 0.4 diffuse 0.6 }
  normal { wrinkles 1  }
}
               
#declare bell= 
union{
  union{
    difference{  
      union{
        object{bellShape}
        torus{70,4 translate<0,117,0>} 
        torus{63,4 translate<0,107,0>} 
      }
      object{bellShape scale <.96,1,.96> translate<0,1,0>}    
    }  
    torus{90,4 translate<0,148,0>} 

    sphere{<0,148,0> ,15}
    box{<-.08,0,.2>,<.08,148,-.2>}
    sphere{<0,22,0> ,30}
    texture{bellMetal scale <200,100,200>/2}  
    rotate<180,0,0> 
//    translate<0,15,0>
//    rotate<-20,0,0> 
//    translate<0,-15,0>
  }

  difference{
    superellipsoid { <.15, .03>  scale<110,65,15> translate<0,10,0> } 
    cylinder{<0,-90,-20>,<0,-90,20>, 97 scale<1,1.5,1>}
    box{<-150,-13,-20>,<150,-17,20>}
    texture{pigment{bellWood scale 20  rotate<89.5,1,89.5>}}  
    texture{pigment{woodCracks rotate<0,0,90> scale <150,20,100>}}
  }                                     
  cylinder{<-115,-15,0>,<130,-15,0>, 8 texture{bell_Iron}} 

  cylinder{<120,-15,0>,<130,-15,0>, 15 texture{bell_Iron}}  

  difference{
    cylinder{<120,-15,0>,<136,-15,0>, 75}  
    cylinder{<110,-15,0>,<150,-15,0>, 65} 
    torus{76,6 rotate<0,0,90> translate<128,-15,0>} 
     texture{bell_Iron}
  } 
 
  #declare yy = 0;
  #while (yy < 30)
    object{oneLink  scale 80 rotate<90,0,90> translate<128,-15-(16*yy),-75>}
    object{oneLink  scale 80 rotate<0,0,90>  translate<128,-15-(16*(yy+1)),-75>} 
    #declare yy = yy + 2;
  #end

  object{oneLink  scale 80 rotate<0,0,90> 
    translate<0,0,-75> rotate<12,0,0> translate<128,-15,0> 
  } 

  object{oneLink  scale 80 rotate<90,0,90>
    translate<0,0,-75> rotate<24,0,0> translate<128,-15,0> 
  } 

  object{oneLink  scale 80 rotate<0,0,90> 
    translate<0,0,-75> rotate<36,0,0> translate<128,-15,0> 
  }      

  object{oneLink  scale 80 rotate<90,0,90>
    translate<0,0,-75> rotate<48,0,0> translate<128,-15,0> 
  } 


  object{oneLink  scale 80 rotate<0,0,90> 
    translate<0,0,-75> rotate<60,0,0> translate<128,-15,0> 
  } 

  object{oneLink  scale 80 rotate<90,0,90>
    translate<0,0,-75> rotate<72,0,0> translate<128,-15,0> 
  } 

  object{oneLink  scale 80 rotate<0,0,90> 
    translate<0,0,-75> rotate<84,0,0> translate<128,-15,0> 
  } 

  object{oneLink  scale 80 rotate<90,0,90>
    translate<0,0,-75> rotate<96,0,0> translate<128,-15,0> 
  } 

  cylinder{<128,0,0>,<128,65,0>, 3 translate<0,-15,0> texture{bell_Iron}} 
  cylinder{<128,0,0>,<128,65,0>, 3 rotate<-72,0,0> translate<0,-15,0> texture{bell_Iron}} 
  cylinder{<128,0,0>,<128,65,0>, 3 rotate<-72*2,0,0> translate<0,-15,0> texture{bell_Iron}} 
  cylinder{<128,0,0>,<128,65,0>, 3 rotate<-72*3,0,0> translate<0,-15,0> texture{bell_Iron}} 
  cylinder{<128,0,0>,<128,65,0>, 3 rotate<-72*4,0,0> translate<0,-15,0> texture{bell_Iron}} 

  box{<-100,-45,-15>,<-75,140,-30> texture{Rusty_Iron scale .3}}
  box{<100,-45,-15>,<75,140,-30> texture{Rusty_Iron scale .3}} 

  sphere{<83,130,-28>, 5  texture{bolt_Rusty_Iron}}
  sphere{<93,115,-28>, 5  texture{bolt_Rusty_Iron}}
  sphere{<83,100,-28>, 5  texture{bolt_Rusty_Iron}}

  sphere{<-83,100,-28>, 5  texture{bolt_Rusty_Iron}}
  sphere{<-93,115,-28>, 5  texture{bolt_Rusty_Iron}}
  sphere{<-83,130,-28>, 5  texture{bolt_Rusty_Iron}} 
 

  sphere{<83,25,-28>, 5  texture{bolt_Rusty_Iron}}
  sphere{<93,0,-28>, 5  texture{bolt_Rusty_Iron}}
  sphere{<83,-30,-28>, 5  texture{bolt_Rusty_Iron}} 

  sphere{<-83,-30,-28>, 5  texture{bolt_Rusty_Iron}}
  sphere{<-93,0,-28>, 5  texture{bolt_Rusty_Iron}}
  sphere{<-83,25,-28>, 5  texture{bolt_Rusty_Iron}} 
}

object{bell scale .015 translate<0,12,-.875>}              